pub enum Stmt {
Edge(Edge),
Node {
id: Identity,
port: Option<Port>,
attr: Option<AttrList>,
},
Attr(AttrType, AttrList),
Equation(Identity, Identity),
SubGraph(SubGraph),
}Expand description
A single line of statement. You should not construct it directly in most cases. We still expose this type because we only implement a subset of dot language so you may need to write special statements on your own.
Variants